package com.example.mobileapp

import android.app.Application
import androidx.room.*
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import androidx.sqlite.db.SupportSQLiteDatabase
import com.example.mobileapp.db.AppDatabase
import com.example.mobileapp.repositories.CategoryRepository
import com.example.mobileapp.repositories.OrderProductRepository
import com.example.mobileapp.repositories.OrderRepository
import com.example.mobileapp.repositories.ProductRepository
import com.example.mobileapp.repositories.RoleRepository
import com.example.mobileapp.repositories.StatusRepository
import com.example.mobileapp.repositories.UserRepository
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.components.SingletonComponent
import javax.inject.Singleton

@Module
@InstallIn(SingletonComponent::class)
object AppModule {
    @Provides
    @Singleton
    fun provideDatabase(app: Application) : AppDatabase {
        return Room.databaseBuilder(
            app,
            AppDatabase::class.java,
            AppDatabase.DB_NAME
        )
            .fallbackToDestructiveMigration()
            .build()
    }

    @Provides
    @Singleton
    fun provideCategoryRepository(db: AppDatabase) = CategoryRepository(db.categoryDao())

    @Provides
    @Singleton
    fun provideOrderProductRepository(db: AppDatabase) = OrderProductRepository(db.orderProductDao())

    @Provides
    @Singleton
    fun provideOrderRepository(db: AppDatabase) = OrderRepository(db.orderDao())

    @Provides
    @Singleton
    fun provideProductRepository(db: AppDatabase) = ProductRepository(db.productDao())

    @Provides
    @Singleton
    fun provideRoleRepository(db: AppDatabase) = RoleRepository(db.roleDao())

    @Provides
    @Singleton
    fun provideStatusRepository(db: AppDatabase) = StatusRepository(db.statusDao())

    @Provides
    @Singleton
    fun provideUserRepository(db: AppDatabase) = UserRepository(db.userDao())
}