package com.example.mobileapp.dao
import androidx.paging.PagingSource
import androidx.room.*
import com.example.mobileapp.models.*
import kotlinx.coroutines.flow.Flow

@Dao
interface OrderDao {
    @Insert
    suspend fun insert(order: Order) : Long
    @Update
    suspend fun update(order: Order)
    @Delete
    suspend fun delete(order: Order)

    @Query("select * from `order`")
    fun getAll() : Flow<List<OrderWithProducts>>
    @Query("select * from `order` where `order`.`id` =:id")
    fun getById(id: Int): Flow<OrderWithProducts>
    @Query("select * from `order` where (`order`.`user_id` =:userId and `order`.`status_id` != 1 and `order`.`status_id` != 4)")
    fun getOrdersByUserId(userId: Int): PagingSource<Int, OrderWithProducts>

    @Query("select * from `order` where `order`.`user_id` =:userId and `order`.`status_id` = 1")
    fun getCartByUserId(userId: Int): Flow<OrderWithProducts?>

    @Query("select * from `order` where `order`.`status_id` != 1 and `order`.`status_id` != 4")
    fun getOrdersToWork(): PagingSource<Int, OrderWithProducts>
}