package com.example.mobileapp.dao
import androidx.room.*
import com.example.mobileapp.models.CategoryWithProducts
import com.example.mobileapp.models.Product
import kotlinx.coroutines.flow.Flow
import androidx.paging.PagingSource

@Dao
interface ProductDao {
    @Insert
    suspend fun insert(product: Product)
    @Update
    suspend fun update(product: Product)
    @Delete
    suspend fun delete(product: Product)

    @Query("select * from product")
    fun getAll() : Flow<List<Product>>
    @Query("select * from product where product.id = :id")
    fun getById(id: Int): Flow<Product>
    @Query("select * from product where product.category_id = :categoryId")
    fun getProductsByCategoryId(categoryId: Int) : PagingSource<Int, Product>
    @Query("select * from category")
    fun getCategoriesWithProducts() : PagingSource<Int, CategoryWithProducts>
}