package com.example.mobileapp.repositories

import com.example.mobileapp.dao.OrderDao
import androidx.paging.*
import com.example.mobileapp.dao.OrderProductDao
import com.example.mobileapp.models.Order
import com.example.mobileapp.models.OrderProduct
import com.example.mobileapp.models.OrderWithProducts
import kotlinx.coroutines.flow.Flow
import javax.inject.Inject

class OrderRepository @Inject constructor(
    private val orderDao: OrderDao
){
    suspend fun insert(order: Order):Long  {
        return orderDao.insert(order)
    }
    suspend fun update(order: Order) = orderDao.update(order)
    suspend fun delete(order: Order) = orderDao.delete(order)
    fun getAll() = orderDao.getAll()
    fun getById(id: Int) = orderDao.getById(id)
    fun getOrdersByUserId(userId: Int) = Pager(
        PagingConfig(
            pageSize = 3,
            enablePlaceholders = false
        ),
        pagingSourceFactory = { orderDao.getOrdersByUserId(userId) }
    ).flow
    fun getCartByUserId(userId: Int) : Flow<OrderWithProducts?> {
        return orderDao.getCartByUserId(userId)
    }
    fun getOrdersToWork() = Pager(
        PagingConfig(
            pageSize = 3,
            enablePlaceholders = false
        ),
        pagingSourceFactory = { orderDao.getOrdersToWork() }
    ).flow
}