package com.example.mobileapp.repositories

import androidx.paging.Pager
import androidx.paging.PagingConfig
import androidx.paging.PagingSource
import com.example.mobileapp.dao.ProductDao
import com.example.mobileapp.dao.RoleDao
import com.example.mobileapp.models.OrderWithProducts
import com.example.mobileapp.models.Product
import com.example.mobileapp.models.Role
import kotlinx.coroutines.flow.Flow
import javax.inject.Inject

class ProductRepository @Inject constructor(
    private val productDao: ProductDao
){
    suspend fun insert(product: Product) = productDao.insert(product)
    suspend fun update(product: Product) = productDao.update(product)
    suspend fun delete(product: Product) = productDao.delete(product)
    fun getAll() = productDao.getAll()
    fun getById(id: Int) = productDao.getById(id)
    fun getProductsByCategoryId(categoryId: Int) = Pager(
        PagingConfig(
            pageSize = 3,
            enablePlaceholders = false
        ),
        pagingSourceFactory = { productDao.getProductsByCategoryId(categoryId) }
    ).flow

    fun getCategoriesWithProducts() = Pager(
        PagingConfig(
            pageSize = 3,
            enablePlaceholders = false
        ),
        pagingSourceFactory = { productDao.getCategoriesWithProducts() }
    ).flow
}