package com.example.mobileapp.repositories

import androidx.paging.Pager
import androidx.paging.PagingConfig
import com.example.mobileapp.dao.RoleDao
import com.example.mobileapp.dao.UserDao
import com.example.mobileapp.models.Role
import com.example.mobileapp.models.User
import javax.inject.Inject

class UserRepository @Inject constructor(
    private val userDao: UserDao
){
    suspend fun insert(user: User) = userDao.insert(user)
    suspend fun update(user: User) = userDao.update(user)
    suspend fun delete(user: User) = userDao.delete(user)
    fun getAll() = userDao.getAll()
    fun getAllPaged() = Pager(
        PagingConfig(
            pageSize = 6,
            enablePlaceholders = false
        ),
        pagingSourceFactory = { userDao.getAllPaged() }
    ).flow
    fun getById(id: Int) = userDao.getById(id)
    fun getByLoginAndPassword(login: String, password: String) = userDao.getByLoginAndPassword(login, password)
}