package com.example.mobileapp.screens

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Card
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.ExposedDropdownMenuDefaults
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.OutlinedButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.material3.lightColorScheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.livedata.observeAsState
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.input.TextFieldValue
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavController
import com.example.mobileapp.R
import com.example.mobileapp.navigation.Screens
import com.example.mobileapp.viewmodels.ProductViewModel
import com.example.mobileapp.widgets.Header

@Composable
fun CreateProductScreen(navController: NavController){
    Column (
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
    ) {
        Header(Color(212, 206, 203))
        CreateProductCard(navController)
    }
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun CreateProductCard(navController: NavController){
    val productViewModel: ProductViewModel = hiltViewModel<ProductViewModel>()
    val title = remember { mutableStateOf(TextFieldValue("")) }
    val price = remember { mutableStateOf(TextFieldValue("")) }
    val categoryList = remember { mutableStateListOf(productViewModel.categories) }
    var selectedCategory by remember { mutableStateOf("") }
    var expanded by remember { mutableStateOf(false) }
    val success = productViewModel.successState.observeAsState().value

    if (success == true) {
        navController.navigate(Screens.ManagmentScreen.name)
    }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .background(Color(212, 206, 203)),
        horizontalAlignment = Alignment.CenterHorizontally,
        ) {
        Column(
            modifier = Modifier
                .fillMaxHeight()
                .fillMaxWidth(0.9f)
                .background(Color.White),
            horizontalAlignment = Alignment.CenterHorizontally,
        ) {
            Text(
                text = "Создание блюда",
                color = Color.Black,
                fontFamily = FontFamily(Font(R.font.nunito_extrabold_italic)),
                fontSize = 34.sp,
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(top = 10.dp),
                textAlign = TextAlign.Center,
            )
            Card(
                shape = RoundedCornerShape(20.dp),
                border = BorderStroke(3.dp, Color(222,161,69)),
                modifier = Modifier
                    .padding(top = 15.dp, start = 5.dp, end = 5.dp)
            ){
                Column (
                    modifier = Modifier.background(Color.White)
                ) {
                    OutlinedTextField(
                        value = title.value,
                        onValueChange = {title.value = it},
                        placeholder = { Text(text = "Название", fontSize = 20.sp, color = Color.LightGray) },
                        singleLine = true,

                        shape = RoundedCornerShape(20.dp),
                        textStyle = TextStyle(fontSize = 20.sp),
                        colors = TextFieldDefaults.outlinedTextFieldColors(
                            textColor = Color.Black,
                            disabledTextColor = Color.Transparent,
                            containerColor = Color.White,
                            focusedBorderColor = Color(222,161,69),
                            unfocusedBorderColor = Color(222,161,69),
                        ),
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(top = 20.dp, start = 20.dp, end = 20.dp),
                    )
                    Card(
                        shape = RoundedCornerShape(20.dp),
                        border = BorderStroke(1.dp, Color(222,161,69)),
                        modifier = Modifier.fillMaxWidth().padding(top = 20.dp, start = 20.dp, end = 20.dp),
                    ){
                        MaterialTheme(
                            colorScheme = lightColorScheme(
                                surfaceVariant= Color.White,
                                surface = Color.White,
                                onSurface = Color.Gray
                            )
                        ){
                            ExposedDropdownMenuBox(
                                expanded = expanded,
                                onExpandedChange = {
                                    expanded = !expanded
                                },
                            ) {
                                TextField(
                                    modifier = Modifier
                                        .menuAnchor().fillMaxWidth(),
                                    readOnly = true,
                                    value = selectedCategory,
                                    onValueChange = {},
                                    label = { Text("Категория") },
                                    trailingIcon = { ExposedDropdownMenuDefaults.TrailingIcon(expanded = expanded) },
                                )

                                ExposedDropdownMenu(
                                    expanded = expanded,
                                    onDismissRequest = {
                                        expanded = false
                                    },
                                ) {
                                    categoryList.first().forEach { selectionOption ->
                                        DropdownMenuItem(
                                            text = { Text(selectionOption) },
                                            onClick = {
                                                selectedCategory = selectionOption
                                                expanded = false
                                            },
                                            contentPadding = ExposedDropdownMenuDefaults.ItemContentPadding,
                                        )
                                    }
                                }
                            }
                        }
                    }
                    OutlinedTextField(
                        value = price.value,
                        onValueChange = {price.value = it},
                        placeholder = { Text(text = "Цена", fontSize = 20.sp, color = Color.LightGray) },
                        singleLine = true,

                        shape = RoundedCornerShape(20.dp),
                        textStyle = TextStyle(fontSize = 20.sp),
                        colors = TextFieldDefaults.outlinedTextFieldColors(
                            textColor = Color.Black,
                            disabledTextColor = Color.Transparent,
                            containerColor = Color.White,
                            focusedBorderColor = Color(222,161,69),
                            unfocusedBorderColor = Color(222,161,69),
                        ),
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(top = 20.dp, start = 20.dp, end = 20.dp),
                    )
                    OutlinedButton(
                        onClick = {
                            productViewModel.addProduct(title.value.text, selectedCategory, price.value.text)
                        },
                        border = BorderStroke(4.dp, Color(222,161,69)),
                        shape = RoundedCornerShape(20.dp),
                        colors = ButtonDefaults.outlinedButtonColors(Color(255,186,83)),
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(20.dp),
                    ) {
                        Text(
                            text = "Сохранить",
                            fontFamily = FontFamily(Font(R.font.nunito_extrabold_italic)),
                            fontSize = 30.sp,
                            color = Color.White
                        )
                    }
                }
            }
        }
    }
}