package com.example.mobileapp.viewmodels

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.mobileapp.PreferencesManager
import com.example.mobileapp.models.Category
import com.example.mobileapp.models.Role
import com.example.mobileapp.models.Status
import com.example.mobileapp.models.User
import com.example.mobileapp.repositories.CategoryRepository
import com.example.mobileapp.repositories.RoleRepository
import com.example.mobileapp.repositories.StatusRepository
import com.example.mobileapp.repositories.UserRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.first
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class AuthorizationViewModel @Inject constructor(
    private val userRepository: UserRepository,
    private val categoryRepository: CategoryRepository,
    private val roleRepository: RoleRepository,
    private val statusRepository: StatusRepository,
) : ViewModel() {
    private val _successState = MutableLiveData<Boolean?>()
    val successState: LiveData<Boolean?>
        get() = _successState

    init {
        addAdmin()
    }

    fun calmSuccessState() {
        _successState.postValue(null)
    }

    fun login(sharedPref: PreferencesManager, login: String, password: String) {
        viewModelScope.launch {
            userRepository.getByLoginAndPassword(login, password).collect {
                if (it == null) {
                    _successState.postValue(false)
                } else {
                    sharedPref.saveData("userId", it.id.toString())
                    sharedPref.saveData("userRole", roleRepository.getById(it.roleId).first().name)
                    _successState.postValue(true)
                }
            }
        }
    }

    private fun addAdmin() {
        viewModelScope.launch {
            userRepository.getAll().collect {
                if (it.size == 0) {
                    roleRepository.insert(Role(1, "admin"))
                    roleRepository.insert(Role(2, "worker"))
                    roleRepository.insert(Role(3, "user"))
                    statusRepository.insert(Status(1, "Корзина"))
                    statusRepository.insert(Status(2, "Принят"))
                    statusRepository.insert(Status(3, "Готов"))
                    statusRepository.insert(Status(4, "Выдан"))
                    categoryRepository.insert(Category(1, "Бургеры"))
                    categoryRepository.insert(Category(2, "Картошка"))
                    categoryRepository.insert(Category(3, "Напитки"))
                    userRepository.insert(User(1, "admin", "admin", 1))
                }
            }
        }
    }
}