package com.example.mobileapp.viewmodels

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.mobileapp.PreferencesManager
import com.example.mobileapp.models.OrderProduct
import com.example.mobileapp.models.OrderWithProducts
import com.example.mobileapp.models.User
import com.example.mobileapp.repositories.OrderProductRepository
import com.example.mobileapp.repositories.OrderRepository
import com.example.mobileapp.repositories.StatusRepository
import com.example.mobileapp.repositories.UserRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.first
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class CartViewModel @Inject constructor(
    private val orderRepository: OrderRepository,
    private val orderProductRepository: OrderProductRepository,
    private val statusRepository: StatusRepository,
    private val userRepository: UserRepository
) : ViewModel() {
    private val _user = MutableLiveData<User>()
    val user: LiveData<User>
        get() = _user
    private val _cart = MutableLiveData<OrderWithProducts?>()
    val cart: LiveData<OrderWithProducts?>
        get() = _cart

    fun retrieveUser(sharedPref: PreferencesManager) {
        val userId = sharedPref.getData("userId", "-1").toInt()

        if (userId == -1) return

        viewModelScope.launch {
            userRepository.getById(userId).collect {
                _user.postValue(it)
            }
        }
        viewModelScope.launch {
            orderRepository.getCartByUserId(userId).collect{
                _cart.postValue(it)
            }
        }
    }

    fun makeOrder() {
        viewModelScope.launch {
            val model = cart.value!!.order
            model.statusId = statusRepository.getByName("Принят").first().id!!
            orderRepository.update(model)
        }
    }

    fun removeProductFromOrder(productId: Int) {
        val orderModel = cart.value!!.order
        var productModel : OrderProduct? = null

        cart.value!!.orderWithProducts.map {
            if (it.orderProduct.productId == productId){
                productModel = it.orderProduct
                orderModel.price -= it.product.price
            }
        }

        if(productModel!!.amount == 1) {
            // delete
            viewModelScope.launch {
                orderRepository.update(orderModel)
                orderProductRepository.delete(productModel!!)
            }
        }
        else{
            // update
            productModel!!.amount -= 1
            viewModelScope.launch {
                orderRepository.update(orderModel)
                orderProductRepository.update(productModel!!)
            }
        }
    }
    fun addProductToOrder(productId: Int) {
        val orderModel = cart.value!!.order
        var productModel : OrderProduct? = null
        cart.value!!.orderWithProducts.map {
            if (it.orderProduct.productId == productId){
                productModel = it.orderProduct
                orderModel.price += it.product.price
            }
        }
        // update
        productModel!!.amount += 1
        viewModelScope.launch {
            orderRepository.update(orderModel)
            orderProductRepository.update(productModel!!)
        }
    }
}