package com.example.mobileapp.viewmodels

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.paging.PagingData
import com.example.mobileapp.PreferencesManager
import com.example.mobileapp.models.CategoryWithProducts
import com.example.mobileapp.models.Order
import com.example.mobileapp.models.OrderProduct
import com.example.mobileapp.models.Product
import com.example.mobileapp.models.User
import com.example.mobileapp.repositories.CategoryRepository
import com.example.mobileapp.repositories.OrderProductRepository
import com.example.mobileapp.repositories.OrderRepository
import com.example.mobileapp.repositories.ProductRepository
import com.example.mobileapp.repositories.UserRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.launch
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.first
import javax.inject.Inject

@HiltViewModel
class MenuViewModel @Inject constructor(
    private val productRepository: ProductRepository,
    private val orderRepository: OrderRepository,
    private val orderProductRepository: OrderProductRepository,
    private val userRepository: UserRepository
) : ViewModel() {
    private val _user = MutableLiveData<User>()
    val user: LiveData<User>
        get() = _user

    fun retrieveUser(sharedPref: PreferencesManager) {
        val userId = sharedPref.getData("userId", "-1").toInt()

        if (userId == -1) return

        viewModelScope.launch {
            userRepository.getById(userId).collect {
                _user.postValue(it)
            }
        }
    }

    val categoiesWithProductsListUiState: Flow<PagingData<CategoryWithProducts>> = productRepository.getCategoriesWithProducts()

    fun deleteProduct(product : Product) {
        viewModelScope.launch {
            productRepository.delete(product)
        }
    }

    fun addProductToCart(productId: Int) {

        viewModelScope.launch {
            val product = productRepository.getById(productId).first()
            val order = orderRepository.getCartByUserId(user.value?.id!!).first()
            if (order == null) {
                val newOrderId = orderRepository.insert(Order(null, user.value?.id!!, product.price, 1 ))
                orderProductRepository.insert(OrderProduct(newOrderId.toInt(), productId, 1))
            }
            else {
                var isAlreadyAdded = false
                for (prod in order.orderWithProducts) {
                    if (prod.product.id == productId) {
                        val newOrderProduct = prod.orderProduct
                        newOrderProduct.amount += 1
                        val newOrder = order.order
                        newOrder.price += prod.product.price
                        orderProductRepository.update(newOrderProduct)
                        orderRepository.update(newOrder)
                        isAlreadyAdded = true
                    }
                }
                if (!isAlreadyAdded) {
                    orderProductRepository.insert(OrderProduct(order.order.id!!, productId, 1))
                    val newOrder = order.order
                    newOrder.price += product.price
                    orderRepository.update(newOrder)
                }
            }
        }
    }
}