package com.example.mobileapp.viewmodels

import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.paging.PagingData
import com.example.mobileapp.models.OrderWithProducts
import com.example.mobileapp.repositories.OrderRepository
import com.example.mobileapp.repositories.StatusRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.first
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class OrderViewModel @Inject constructor(
    private val statusRepository: StatusRepository,
    private val orderRepository: OrderRepository
) : ViewModel() {
    val orderList = MutableLiveData<Flow<PagingData<OrderWithProducts>>>()

    init {
        updateOrderList()
    }

    private fun updateOrderList(){
        orderList.postValue(orderRepository.getOrdersToWork())
    }

    suspend fun getOrderStatus(statusId: Int) : String{
        return statusRepository.getById(statusId).first().name
    }

    fun changeOrderStatus(orderId: Int) {
        viewModelScope.launch {
            val order = orderRepository.getById(orderId).first()

            when(statusRepository.getById(order.order.statusId).first().name){
                "Принят" -> {
                    val newOrder = order.order
                    newOrder.statusId = statusRepository.getByName("Готов").first().id!!
                    orderRepository.update(newOrder)
                }
                "Готов" -> {
                    val newOrder = order.order
                    newOrder.statusId = statusRepository.getByName("Выдан").first().id!!
                    orderRepository.update(newOrder)
                }
            }

            updateOrderList()

            // для удобства
            if (orderRepository.getById(orderId).first().order.statusId == 4){
                orderRepository.delete(orderRepository.getById(orderId).first().order)
            }
        }
    }
}