package com.example.mobileapp.viewmodels

import androidx.compose.ui.platform.LocalContext
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.VIEW_MODEL_STORE_OWNER_KEY
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.paging.Pager
import androidx.paging.PagingData
import com.example.mobileapp.PreferencesManager
import com.example.mobileapp.models.CategoryWithProducts
import com.example.mobileapp.models.OrderWithProducts
import com.example.mobileapp.models.User
import com.example.mobileapp.repositories.OrderRepository
import com.example.mobileapp.repositories.StatusRepository
import com.example.mobileapp.repositories.UserRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.first
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class ProfileViewModel @Inject constructor(
    private val orderRepository: OrderRepository,
    private val statusRepository: StatusRepository
) : ViewModel() {
    fun getActiveOrders(userId : Int) : Flow<PagingData<OrderWithProducts>>? {
        if (userId == -1) return null
        return orderRepository.getOrdersByUserId(userId)
    }

    suspend fun getOrderStatus(statusId: Int) : String{
        return statusRepository.getById(statusId).first().name
    }

    fun logout(sharedPref: PreferencesManager) {
        sharedPref.deleteData("userId")
        sharedPref.deleteData("userRole")
    }
}