package com.example.mobileapp.viewmodels

import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.remember
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.paging.PagingData
import com.example.mobileapp.PreferencesManager
import com.example.mobileapp.models.OrderWithProducts
import com.example.mobileapp.models.Role
import com.example.mobileapp.models.User
import com.example.mobileapp.repositories.OrderRepository
import com.example.mobileapp.repositories.RoleRepository
import com.example.mobileapp.repositories.StatusRepository
import com.example.mobileapp.repositories.UserRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.cancellable
import kotlinx.coroutines.flow.collect
import kotlinx.coroutines.flow.filter
import kotlinx.coroutines.flow.first
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class UsersViewModel @Inject constructor(
    private val roleRepository: RoleRepository,
    private val userRepository: UserRepository
) : ViewModel() {
    private val _roles = mutableStateListOf<String>()
    val roles: List<String>
        get() = _roles

    init {
        viewModelScope.launch {
            roleRepository.getAll().collect{data ->
                _roles.addAll(data.map { role -> role.name })
            }
        }
    }

    fun getUsersList() : Flow<PagingData<User>> {
        return userRepository.getAllPaged()
    }

    suspend fun getUserRole(user: User) : String {
        return roleRepository.getById(user.roleId).first().name
    }

    fun changeUserRole(userId: Int, roleName: String) {
        viewModelScope.launch {
            val user = userRepository.getById(userId).first()

            when(roleName){
                "user" -> {
                    val newUser = user
                    user.roleId = roleRepository.getByName("user").first().id!!
                    userRepository.update(newUser)
                }
                "worker" -> {
                    val newUser = user
                    user.roleId = roleRepository.getByName("worker").first().id!!
                    userRepository.update(newUser)
                }
                "admin" -> {
                    val newUser = user
                    user.roleId = roleRepository.getByName("admin").first().id!!
                    userRepository.update(newUser)
                }
            }
        }
    }

    fun deleteUser(userId: Int){
        viewModelScope.launch{
            userRepository.delete(userRepository.getById(userId).first())
        }
    }
}